==> pde-2.12.0.tgz: package/lib/pde.js <==
import DefaultAdapter from './adapters/default';

var PDE = /*#__PURE__*/function () {
  /**
   * @constructor
   * @param {object} param
   * @param {object} param.adapter
   * @param {boolean} param.hasUserConsents
   */
  function PDE(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        adapter = _ref.adapter,
        _ref$hasUserConsents = _ref.hasUserConsents,
        hasUserConsents = _ref$hasUserConsents === void 0 ? true : _ref$hasUserConsents;

    if (!adapter) {
      adapter = new DefaultAdapter();
    }

    this._adapter = adapter;

    this._adapter.updateConsents({
      hasUserConsents: hasUserConsents
    });
  }

  var _proto = PDE.prototype;

  _proto.getEnabledFeatures = function getEnabledFeatures(_temp2) {
    var _ref2 = _temp2 === void 0 ? {} : _temp2,
        attributes = _ref2.attributes;

    return this._adapter.getEnabledFeatures({
      attributes: attributes
    });
  }
  /**
   * @param {object} param
   * @param {string} param.name
   * @param {object} param.attributes
   */
  ;

  _proto.activateExperiment = function activateExperiment(_ref3) {
    var name = _ref3.name,
        attributes = _ref3.attributes;
    return this._adapter.activateExperiment({
      name: name,
      attributes: attributes
    });
  };

  _proto.getInitialData = function getInitialData() {
    return this._adapter.getInitialData();
  }
  /**
   * @param {object} param
   * @param {string} param.name
   * @param {object} param.attributes
   */
  ;

  _proto.getVariation = function getVariation(_ref4) {
    var name = _ref4.name,
        attributes = _ref4.attributes;
    return this._adapter.getVariation({
      name: name,
      attributes: attributes
    });
  }
  /**
   * Checks if a feature flag is active or not
   * @param {object} param
   * @param {string} param.featureKey Feature flag key
   * @parma {object=} param.attributes
   * @returns {boolean}
   */
  ;

  _proto.isFeatureEnabled = function isFeatureEnabled(_ref5) {
    var featureKey = _ref5.featureKey,
        attributes = _ref5.attributes;
    return this._adapter.isFeatureEnabled({
      featureKey: featureKey,
      attributes: attributes
    });
  }
  /**
   * Return all variables of a given feature
   * @param {object} param
   * @param {string} param.featureKey Feature flag key
   * @parma {object=} param.attributes
   * @returns {object}
   */
  ;

  _proto.getAllFeatureVariables = function getAllFeatureVariables(_ref6) {
    var featureKey = _ref6.featureKey,
        attributes = _ref6.attributes;
    return this._adapter.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes
    });
  };

  return PDE;
}();

export { PDE as default };

==> pde-2.19.0.tgz: package/lib/pde.js <==
import DefaultAdapter from './adapters/default.js';

var PDE = /*#__PURE__*/function () {
  /**
   * @constructor
   * @param {object} param
   * @param {object} param.adapter
   * @param {boolean} param.hasUserConsents
   */
  function PDE(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        adapter = _ref.adapter,
        _ref$hasUserConsents = _ref.hasUserConsents,
        hasUserConsents = _ref$hasUserConsents === void 0 ? true : _ref$hasUserConsents;

    if (!adapter) {
      adapter = new DefaultAdapter();
    }

    this._adapter = adapter;

    this._adapter.updateConsents({
      hasUserConsents: hasUserConsents
    });
  }

  var _proto = PDE.prototype;

  _proto.getEnabledFeatures = function getEnabledFeatures(_temp2) {
    var _ref2 = _temp2 === void 0 ? {} : _temp2,
        attributes = _ref2.attributes,
        adapterId = _ref2.adapterId;

    return this._adapter.getEnabledFeatures({
      attributes: attributes,
      adapterId: adapterId
    });
  }
  /**
   * @param {object} param
   * @param {string} param.name
   * @param {object} param.attributes
   */
  ;

  _proto.activateExperiment = function activateExperiment(_ref3) {
    var name = _ref3.name,
        attributes = _ref3.attributes,
        adapterId = _ref3.adapterId;
    return this._adapter.activateExperiment({
      name: name,
      attributes: attributes,
      adapterId: adapterId
    });
  };

  _proto.getInitialData = function getInitialData() {
    return this._adapter.getInitialData();
  }
  /**
   * @param {object} param
   * @param {string} param.name
   * @param {object} param.attributes
   */
  ;

  _proto.getVariation = function getVariation(_ref4) {
    var name = _ref4.name,
        attributes = _ref4.attributes,
        adapterId = _ref4.adapterId;
    return this._adapter.getVariation({
      name: name,
      attributes: attributes,
      adapterId: adapterId
    });
  }
  /**
   * Checks if a feature flag is active or not
   * @param {object} param
   * @param {string} param.featureKey Feature flag key
   * @parma {object=} param.attributes
   * @returns {boolean}
   */
  ;

  _proto.isFeatureEnabled = function isFeatureEnabled(_ref5) {
    var featureKey = _ref5.featureKey,
        attributes = _ref5.attributes,
        adapterId = _ref5.adapterId;
    return this._adapter.isFeatureEnabled({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    });
  }
  /**
   * Return all variables of a given feature
   * @param {object} param
   * @param {string} param.featureKey Feature flag key
   * @parma {object=} param.attributes
   * @returns {object}
   */
  ;

  _proto.getAllFeatureVariables = function getAllFeatureVariables(_ref6) {
    var featureKey = _ref6.featureKey,
        attributes = _ref6.attributes,
        adapterId = _ref6.adapterId;
    return this._adapter.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    });
  };

  return PDE;
}();

export { PDE as default };
